### R code from vignette source 'cap-recap.Rnw'

###################################################
### code chunk number 1: cap-recap.Rnw:1-4
###################################################
options(width=70)
options(continue=" ")
library(tools)


###################################################
### code chunk number 2: cap-recap.Rnw:212-214
###################################################
alfl <- read.csv(system.file("csv", "alfl.csv", package="unmarked"))
head(alfl, 5)


###################################################
### code chunk number 3: cap-recap.Rnw:225-228
###################################################
alfl.covs <- read.csv(system.file("csv", "alflCovs.csv",
    package="unmarked"), row.names=1)
head(alfl.covs)


###################################################
### code chunk number 4: cap-recap.Rnw:242-248
###################################################
alfl$captureHistory <- paste(alfl$interval1, alfl$interval2, alfl$interval3, sep="")
alfl$captureHistory <- factor(alfl$captureHistory,
    levels=c("001", "010", "011", "100", "101", "110", "111"))
## Don't do this:
#levels(alfl$id) <- rownames(alfl.covs)
alfl$id <- factor(alfl$id, levels=rownames(alfl.covs))


###################################################
### code chunk number 5: cap-recap.Rnw:260-263
###################################################
alfl.v1 <- alfl[alfl$survey==1,]
alfl.H1 <- table(alfl.v1$id, alfl.v1$captureHistory)
head(alfl.H1, 5)


###################################################
### code chunk number 6: cap-recap.Rnw:290-302
###################################################
crPiFun <- function(p) {
    p1 <- p[,1]
    p2 <- p[,2]
    p3 <- p[,3]
    cbind("001" = (1-p1) * (1-p2) * p3,
          "010" = (1-p1) * p2     * (1-p3),
          "011" = (1-p1) * p2     * p3,
          "100" = p1     * (1-p2) * (1-p3),
          "101" = p1     * (1-p2) * p3,
          "110" = p1     * p2     * (1-p3),
          "111" = p1     * p2     * p3)
}


###################################################
### code chunk number 7: cap-recap.Rnw:311-314
###################################################
p <- matrix(0.4, 2, 3)
crPiFun(p)
rowSums(crPiFun(p))


###################################################
### code chunk number 8: cap-recap.Rnw:332-333
###################################################
o2y <- matrix(1, 3, 7)


###################################################
### code chunk number 9: cap-recap.Rnw:342-349
###################################################
library(unmarked)
intervalMat <- matrix(c('1','2','3'), 50, 3, byrow=TRUE)
class(alfl.H1) <- "matrix"
umf.cr1 <- unmarkedFrameMPois(y=alfl.H1,
    siteCovs=alfl.covs[,c("woody", "struct", "time.1")],
    obsCovs=list(interval=intervalMat),
    obsToY=o2y, piFun="crPiFun")


###################################################
### code chunk number 10: cap-recap.Rnw:366-369
###################################################
M0 <- multinomPois(~1 ~1, umf.cr1)
Mt <- multinomPois(~interval-1 ~1, umf.cr1)
Mc <- multinomPois(~time.1 ~1, umf.cr1)


###################################################
### code chunk number 11: cap-recap.Rnw:378-379
###################################################
(M0.woody <- multinomPois(~1 ~woody, umf.cr1))


###################################################
### code chunk number 12: woody
###################################################
nd <- data.frame(woody=seq(0, 0.8, length=50))
E.abundance <- predict(M0.woody, type="state", newdata=nd, appendData=TRUE)
plot(Predicted ~ woody, E.abundance, type="l", ylim=c(0, 6),
     ylab="Alder flycatchers / plot", xlab="Woody vegetation cover")
lines(lower ~ woody, E.abundance, col=gray(0.7))
lines(upper ~ woody, E.abundance, col=gray(0.7))


###################################################
### code chunk number 13: cap-recap.Rnw:408-409
###################################################
backTransform(M0.woody, type="det")


###################################################
### code chunk number 14: cap-recap.Rnw:417-418
###################################################
round(getP(M0.woody), 2)[1,]


###################################################
### code chunk number 15: cap-recap.Rnw:444-455
###################################################
crPiFun.Mb <- function(p) { # p should have 3 columns
    pNaive <- p[,1]
    pWise <- p[,3]
    cbind("001" = (1-pNaive) * (1-pNaive) * pNaive,
          "010" = (1-pNaive) * pNaive     * (1-pWise),
          "011" = (1-pNaive) * pNaive     * pWise,
          "100" = pNaive     * (1-pWise)  * (1-pWise),
          "101" = pNaive     * (1-pWise)  * pWise,
          "110" = pNaive     * pWise      * (1-pWise),
          "111" = pNaive     * pWise      * pWise)
}


###################################################
### code chunk number 16: cap-recap.Rnw:468-474
###################################################
behavior <- matrix(c('Naive','Naive','Wise'), 50, 3, byrow=TRUE)
umf.cr1Mb <- unmarkedFrameMPois(y=alfl.H1,
    siteCovs=alfl.covs[,c("woody", "struct", "time.1")],
    obsCovs=list(behavior=behavior),
    obsToY=o2y, piFun="crPiFun.Mb")
M0 <- multinomPois(~1 ~1, umf.cr1Mb)


###################################################
### code chunk number 17: cap-recap.Rnw:479-480
###################################################
(Mb <- multinomPois(~behavior-1 ~1, umf.cr1Mb))


###################################################
### code chunk number 18: cap-recap.Rnw:486-487
###################################################
plogis(confint(Mb, type="det", method="profile"))


###################################################
### code chunk number 19: cap-recap.Rnw:529-538
###################################################
alfl.H <- table(alfl$id, alfl$captureHistory, alfl$survey)
alfl.Hmat <- cbind(alfl.H[,,1], alfl.H[,,2], alfl.H[,,3])
nVisits <- 3
o2yGMM <- kronecker(diag(nVisits), o2y)
umf.cr <- unmarkedFrameGMM(y=alfl.Hmat,
    siteCovs=alfl.covs[,c("woody", "struct")],
    yearlySiteCovs=list(date=alfl.covs[,3:5], time=alfl.covs[,6:8]),
    obsCovs=list(interval=cbind(intervalMat,intervalMat,intervalMat)),
    obsToY=o2yGMM, piFun="crPiFun", numPrimary=nVisits)


###################################################
### code chunk number 20: cap-recap.Rnw:557-558
###################################################
(fm1 <- gmultmix(~woody, ~1, ~time+date, umf.cr))


